.. abrechnung documentation master file, created by
   sphinx-quickstart on Wed Dec 29 11:07:10 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to abrechnung's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. toctree::
   :maxdepth: 2
   :caption: Usage

   usage/installation.rst
   usage/configuration.rst


.. toctree::
   :maxdepth: 2
   :caption: Development

   development/contributing.rst
   development/setup.rst
   development/architecture.rst
   development/packaging.rst
   development/api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
